#!/bin/bash

echo "Do commit!"
# no quotes in regular expression!
if ! [[ "$tmp" =~ ^/tmp/. ]]; then
    echo "Invalid context "$tmp". No commit done!" >&2
    exit 1
fi

# WPA supplicant reload
if [ -r "$tmp/wlan.list" ]; then
    while read i; do
        if [ -n "$i" ] && [ -r "$tmp/wpa_supplicant-$i.conf" ]; then
            if ! diff -q "$tmp/wpa_supplicant-$i.conf" "/etc/wpa_supplicant//wpa_supplicant-$i.conf" >/dev/null 2>&1; then
                cp "$tmp/wpa_supplicant-$i.conf" "/etc/wpa_supplicant//wpa_supplicant-$i.conf"
                echo "Reload wpa_supplicant for interface $i"
                systemctl reload-or-restart "wpa_supplicant@$i"
            fi
        fi
    done < "$tmp/wlan.list"
fi

if [ -r "$tmp/route.list" ] && [ -r "$tmp/to_check_route.list" ]; then
    . "$lib/net-mask.sh"
    while read net mask iface; do
        while read gw route; do
            if [ "$net" = "$(cidr_to_net $gw $mask)" ]; then
                mkdir -p "$tmp/20-$iface.network.d"
                cp "$tmp/route-$route.conf" "$tmp/20-$iface.network.d" || true
            fi
        done <"$tmp/route.list"
    done <"$tmp/to_check_route.list"
fi

pushd . > /dev/null
if cd /etc/systemd/network; then
    shopt -s nullglob
    for i in 20-*.netdev; do
        if ! [ -r "$tmp/$i" ] || ! diff -q "$tmp/$i" "$i" >/dev/nul 2>&1; then
            i=${i#20-}
            i=${i%.netdev}
            echo "Deleting old/redefined virtual interface $i"
            networkctl delete $i || true
            if ! [ -r "$tmp/20-$i.netdev" ]; then
                rm -f "20-$i.netdev"
                rm -f "20-$i.network"
                rm -rf "20-$i.network.d"
            fi
        fi
    done
    # Clear interfaces old properties
    for i in 20-*.network.d/*; do
        if ! [ -r "$tmp/$i" ]; then
            rm -f "$i"
        fi
    done
    # Clear old interface definitions
    for i in 20-*.network; do
        if ! [ -r "$tmp/$i" ]; then
            rm -f "$i"
            rm -rf "${i}.d"
        fi
    done
    # delete possible network setting created by altboot
    find . -maxdepth 1 -name 10-\*.network  -delete
    find . -maxdepth 1 -name 10-\*.netdev  -delete
    shopt -u nullglob

    # Copy new configs
    echo "Copying new configs to $PWD"
    find "$tmp" -name "20-*.network" -type f -exec cp \{\} . \;
    find "$tmp" -name "20-*.netdev" -type f -exec cp \{\} \. \;
    find "$tmp" -name "20-*.network.d" -type d -exec cp -r \{\} . \;
    networkctl reload
fi
popd > /dev/null

if [ -r "$tmp/lte.enable" ]; then
    if ! systemctl is-enabled -q  unipi-lte; then
        systemctl enable unipi-lte || true
    fi
    if [ -r "$tmp/lte.config" ]; then
        if cp "$tmp/lte.config" "$UNIPI_LTE_CONFIG"; then
            systemctl stop unipi-lte || true
        fi
    fi
    if ! systemctl is-active -q  unipi-lte; then
        systemctl start unipi-lte || true
    fi
elif [ -r "$tmp/lte.disable" ]; then
    if systemctl is-enabled -q  unipi-lte; then
        systemctl disable unipi-lte || true
    fi
    if systemctl is-active -q  unipi-lte; then
        systemctl stop unipi-lte || true
    fi
fi

# cleaning...
echo "Clearing temporary directory"
rm -rf "$tmp"
