#!/bin/bash

function update_confile()
{
    # check whether the key:value pair is already in the config
    if grep -q "^${1}:.*${2}" "$tmp/lte.config"; then
        # yes it is, nothing to update
        echo "The key \"$1\" with value $2 is already present"
        return 0
    fi

    # the key:value pair is not present or active, we should change the config

    # check whether the key is there, even commented
    if grep -q "^;*${1}:" "$tmp/lte.config"; then
        # the key is there, we will mangle its value and leave the comment, if there is any
        sed -i "s/^;*${1}:[^;]*/${1}: ${2} /I" "$tmp/lte.config"
        echo "The key $1 is already present, but with different value or commented out => changing"
    else
        # the key is not present at all, add it after start of the [MAIN] section
        sed -i "/\\[MAIN\\]/a ${1}: ${2}" "$tmp/lte.config"
        echo "The key $1 is not present at all => adding"
    fi

    return 1
}

function force_comment()
{
    if grep -q "^${1}:" "$tmp/lte.config"; then
        # if the parameter is uncommented, comment it
        echo "Forcing comment on $1"
        sed -i "s/\\(^$1:.*\\)/;\\1/I" "$tmp/lte.config"
        return 1
    fi
    return 0
}

if [ "$state" != "0" ]; then
    touch "$tmp/lte.enable"
    cp "$UNIPI_LTE_CONFIG" "$tmp/lte.config"
    rmcfg=1
    if ! update_confile "apn" "\"IP\",\"${apn}\""; then
        unset rmcfg
    fi
    if [ "$pin" == "" ]; then
        # pin is empty, comment out the respecitve line
        if ! force_comment "pin"; then
            unset rmcfg
        fi
    elif ! update_confile "pin" "${pin}"; then
        unset rmcfg
    fi
    if [ -n "$rmcfg" ]; then rm "$tmp/lte.config"; fi
else
    touch "$tmp/lte.disable"
fi
