#!/bin/bash

# reset the variables in case they already contain something
unset server port period

# now iterate over the rest of the parameters
# if the parameter will be a known key, we will store the next parameter as its value
while [ -n "$1" ]; do
    case "$1" in
    server)
        shift
        # save the server name, but strip any double quotes, which are escaped unfortunatelly
        server="$(echo $1 | tr -d '\"')"
        ;;
    port)
        shift
        port=$1
        ;;
    period)
        shift
        period=$1
        ;;
    *)
        echo "Unknown parameter" >&2
        ;;
    esac
    shift
done

ntp_conf_dir=/etc/systemd/timesyncd.conf.d
if [ "$server" == "" ] || [ "$server" == "port" ]; then
        # disable the NTP syncing ???
        #timedatectl set-ntp off
        rm -f "$ntp_conf_dir/ntp-server.conf"
else
        echo "Enabling the NTP, server: $server"
        # set the server
        mkdir -p "$ntp_conf_dir"
        export server port period
        envsubst < ${templates}/ntp-server.conf > "$ntp_conf_dir/ntp-server.conf"
        chmod o+rx "$ntp_conf_dir"
        chmod o+r "$ntp_conf_dir/ntp-server.conf"
        # set the syncing
        timedatectl set-ntp on
fi

systemctl try-restart systemd-timesyncd.service

sync
