#!/bin/bash


# Variables using:
# - service
# - CLOUDACCESS_TMP
# - CLOUDACCESS_FINAL

is_on="$1"

export is_on

# check the on/off parameter
if [ "$is_on" = "on" ]; then 
    is_on=1
elif [ "$is_on" = "off" ]; then 
    is_on=0
else
    echo "Missing parameter for service $service : on/off" >&2
    exit 1
fi

SERVICE=merviscloudaccess
# do we have the "on/off" parameter?
if [ -z "$is_on" ]; then 
    # no, we need to
    echo "Missing on/off parameter" >&2
    exit 1
fi

# yes we have on/off parameter
if [ "$is_on" == "1" ]; then
    # cloudaccess should be turned on
    if [ -f "$CLOUDACCESS_TMP" ]; then
        echo -n "CloudAccess config file present in $CLOUDACCESS_TMP, moving to $CLOUDACCESS_FINAL ... "
        if ! mv "$CLOUDACCESS_TMP" "$CLOUDACCESS_FINAL"; then
            echo FAILED
        else
            echo OK

            # check whether the service is already enabled
            if ! systemctl is-enabled $SERVICE >/dev/null 2>&1; then
               # no, enable it
                echo -n "Enabling $SERVICE service ... "
                if ! systemctl enable $SERVICE 2>/dev/null; then
                    echo FAILED
                else
                    echo OK
                fi
            fi

            # check whether the service is already running
            if systemctl is-active $SERVICE >/dev/null 2>&1; then
                # yes, restart it
                echo -n "CloudAccess is running, restarting $SERVICE service ... "
                if ! systemctl restart $SERVICE 2>/dev/null; then
                    echo FAILED
                else
                    echo OK
                fi
            else
                # no, start it
                echo -n "CloudAccess is stopped, starting $SERVICE service ... "
                if ! systemctl start $SERVICE 2>/dev/null; then
                    echo FAILED
                else
                    echo OK
                fi
            fi
        fi
    else
        echo "CloudAccess config file is not present in $CLOUDACCESS_TMP, skipping."
    fi
else
    # cloudaccess should be turned off
    echo -n "Stopping $SERVICE ... "
    if ! systemctl stop $SERVICE 2>/dev/null; then
        echo FAILED
    else
        echo OK
    fi
    echo -n "Disabling $SERVICE ... "
    if ! systemctl disable $SERVICE 2>/dev/null; then
        echo FAILED
    else
        echo OK
    fi
fi
