#!/bin/bash

# on/off port 80 on/off port 443 no/yes

# Used variables
# - service
# - NGINX_AVAILABLE
# - NGINX_ENABLED

#" on/off port 80 on/off port 443 no/redirect [443] "
is_on="$1"
port="$3"
is_onssl="$4"
portssl="$6"
redirect="$7"
portredir="$8"

export is_on port is_onssl portssl redirect portredir

# check the on/off parameter
if [ "$is_on" = "on" ]; then 
    is_on=1
elif [ "$is_on" = "off" ]; then 
    is_on=0
else
    echo "Missing parameter for service $service : on/off" >&2
    exit 1
fi

if [ "$is_onssl" = "on" ]; then 
    is_onssl=1
elif [ "$is_onssl" = "off" ]; then 
    is_onssl=0
else
    echo "Missing parameter for service $service : on/off" >&2
    exit 1
fi

# check the redirect parameter
if [ "$redirect" = "redirect" ]; then 
    redirect=1
else
    redirect=0
fi

echo "is_on:$is_on port:$port  is_onssl:$is_onssl portssl:$portssl redir:$redirect"
# yes we have on/off parameter
if [ "$is_on" == "1" ] || [ "$is_onssl" == "1" ]; then
    # web server should be turned on

    # check whether the port is also configured
    port=${port:-80}
    portssl=${portssl:-443}
    portredir=${portredir:-$portssl}
    if [ "$is_on" = "0" ] || [ "$redirect" = "1" ]; then off_prefix="#"; fi
    if [ "$is_onssl" = "0" ]; then  off_prefix_ssl="#"; fi
    # generate the configuration
    # check whether the template file exists
    nginx_template="$templates/nginx-mervis.template"
    if ! [ -r "$nginx_template" ] || ! [ -s "$nginx_template" ]; then
        echo "Nginx template doesn't exist, isn't readable or its size is 0:  $nginx_template" >&2
        exit 1
    fi
    # replace the port in the template with given one and save this confit to the sites-available
    if ! sed "s/___NGINX_PORT___/$port/;
              s/___NGINX_PORTSSL___/$portssl/;
              s/___OFF_PREFIX___/$off_prefix/g;
              s/___OFF_PREFIX_SSL___/$off_prefix_ssl/g;" \
         "$nginx_template" > "$NGINX_AVAILABLE"; then
        echo "Configuration creation failed"
        exit 1
    fi
    nginx_template="$templates/nginx-redir.template"
    if [ "$redirect" = "1" ]; then
        if ! sed "s/___NGINX_PORT___/$port/;
              s/___NGINX_PORTREDIR___/$portredir/" "$nginx_template" >> "$NGINX_AVAILABLE"; then
            echo "Configuration creation failed"
            exit 1
        fi
    fi

    # check whether the nginx sites-enabled symlink exists
    if [ -h "$NGINX_ENABLED" ] && [ "$(readlink -f "$NGINX_ENABLED")" == "$NGINX_AVAILABLE" ]; then
        echo "Symlink from sites-enabled to sites-available already exists and is correct"
    else
        echo "The symlink doesn't exist or doesn't point to $NGINX_AVAILABLE, removing"
        if [ -f "$NGINX_ENABLED" ]; then
            if rm -f "$NGINX_ENABLED"; then
               echo "Unable to remove symlink" >&2
               exit 1
            fi
        else
            echo "Recreating symlink"
            if ! ln -s "$NGINX_AVAILABLE" "$NGINX_ENABLED"; then
                echo "Recreation of symlink failed" >&2
                exit 1
            fi
        fi
    fi

    # check nginx configuration for errors
    echo "Checking nginx configuration"
    if ! nginx -t; then
        echo "Nginx configuration is not valid, see above for more details" >&2
        exit 1
    fi

    # check whether the nginx is enabled
    if [ "$(systemctl is-active nginx)" == "active" ]; then
        # nginx enabled, restart it
        echo "Nginx already enabled, restarting"
        if ! systemctl restart --no-block nginx; then
            echo "Restarting nginx failed" >&2
            exit 1
        fi
    else
        # enable and start the nginx
        echo "Enabling nginx"
        if ! systemctl enable nginx; then
            echo "Enabling nginx failed" >&2
            exit 1
        fi
        echo "Starting nginx"
        if ! systemctl start --no-block nginx; then
            echo "Enabling nginx failed" >&2
            exit 1
        fi
    fi
    # end of section for starting web server
else
    # web server should be turned off
    # check whether the nginx sites-enabled symlink exists
    if [ -h "$NGINX_ENABLED" ]; then
        # it does, remove it
        if ! rm -f "$NGINX_ENABLED"; then
            echo "Symlink $NGINX_ENABLED could not be removed"
        fi
    fi
    # symlink should not exist
    # stop the nginx and disable it
    echo "Stopping and disabling nginx"
    systemctl stop nginx
    systemctl disable nginx
    # end of section for turning off the webserver
fi

# check whether the new MervisFCGI configuration is in the temporary directory
if [ -s /tmp/fcgi.ini.new ]; then
    # it is, move it to the final destination
    echo "MervisFCGI config is present, moving to the final destination"
    if ! mv /tmp/fcgi.ini.new /opt/mervis/fcgi.ini; then
        echo "Moving failed" >&2
        exit 1
    fi
fi
